django-awl
**********

Yet another collection of tools for django.  


Installation
============

.. code-block:: bash

    $ pip install django-awl

Docs
====

Docs available at: http://django-awl.readthedocs.org/en/latest/
